@@ -489,13 +489,13 @@ class CPFclustering:
     for col in range(len(cats)):
       vals, counts = np.unique(X[:, cats[col]], return_counts = True)
       l[col] = len(vals)
-      if metric is 1:
+      if metric == 1:
         w[col] = [1]*len(vals)
       
-      if metric is 2:
+      if metric == 2:
         w[col] = counts/np.sum(counts)
       
-      if metric is 3:
+      if metric == 3:
         w[col] = np.log(counts/np.sum(counts))/(np.sum(np.log(counts/np.sum(counts))))
       
       for i in range(len(vals)):
